/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew;

import java.util.ResourceBundle;
import java.util.logging.Level;

import com.bitctrl.i18n.MessageHandler;

import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * Versorgt die Applikation mit lokalisierten Benutzernachrichten.
 *
 * @author BitCtrl Systems GmbH, Steffen Gieseler
 */
public enum LmsMsg implements MessageHandler, LogNachricht {

	/**
	 * Parameter: 1) Exception-Message.
	 */
	ErrorAppException(Debug.ERROR),
	/**
	 * Parameter: 1) Thread-Name.
	 */
	ErrorThreadBeendet(Debug.ERROR),

	/**
	 * Parameter: 1) Name der Menge. Parameter: 2) LMS-Objekt.
	 */
	ErrorLMSObjektMenge(Debug.ERROR),

	/**
	 * Parameter: 1) dataDescription.
	 */
	ErrorAnmeldungEmpfang(Debug.ERROR),

	/**
	 * Parameter: 1) Dateiname, 2) Fehlermeldung.
	 */
	ErrorTICDatei(Debug.ERROR),

	/**
	 * Parameter: 1) PID des Objektes.
	 */
	ErrorErzeugeObjekt(Debug.ERROR),

	/**
	 * Parameter: 1) Fehlermeldung.
	 */
	ErrorAppBeendet(Debug.ERROR),

	/**
	 * Parameter: 1) Name Landesmeldestelle.
	 */
	WarningStoerungEingehend(Debug.WARNING),

	/**
	 * Parameter: 1) Name Landesmeldestelle.
	 */
	WarningStoerungAusgehend(Debug.WARNING),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	WarningMeldungExistiert(Debug.WARNING),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	WarningMeldungNichtInMenge(Debug.WARNING),

	/**
	 * Parameter: 1) Fehlermeldung.
	 */
	WarningFehlerEreignisDaten(Debug.WARNING),

	/** Ohne Paramater. */
	InfoApplikationStartet(Debug.INFO),

	/** Ohne Paramater. */
	InfoApplikationBeendet(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung, 2) Version.
	 */
	InfoMeldungAktualisiert(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung, 2) Version.
	 */
	InfoMeldungErzeugt(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	InfoMeldungErzeugtFertig(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	InfoMeldungVerworfen(Debug.INFO),

	/**
	 * Parameter: 1) Meldung.
	 */
	InfoMeldungInitialisiert(Debug.INFO),

	/**
	 * Parameter: 1) Name Landesmeldestelle.
	 */
	InfoStatusEingehendOK(Debug.INFO),

	/**
	 * Parameter: 1) Name Landesmeldestelle.
	 */
	InfoStatusAusgehendOK(Debug.INFO),

	/**
	 * Parameter: 1) Dateiname.
	 */
	InfoDateiVerarbeitet(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	InfoMeldungNeu(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	InfoMeldungEntfernt(Debug.INFO),

	/**
	 * Parameter: 1) PID Meldung. (wird auch als Betriebsmeldung versendet,
	 * siehe getBmvLevel)
	 */
	InfoMeldungAufgehoben(Debug.INFO),

	/**
	 * Parameter: 1) PID LMS.
	 */
	InfoBenutzeLMS(Debug.INFO),

	/**
	 * .
	 */
	InfoWarteParameter(Debug.INFO),

	/**
	 * .
	 */
	InfoKeinEmpfang(Debug.INFO),

	/**
	 * .
	 */
	InfoKeinVersand(Debug.INFO),

	/** Parameter: 1) Anzahl Systemobjekte. */
	ConfigMesswertEmpfaengerBereit(Debug.CONFIG),

	/**
	 * Parameter: 1) Dateiname.
	 */
	FineDateiGeloescht(Debug.FINE),

	/**
	 * Parameter: 1) Dateiname.
	 */
	FineDateiGeloeschtAbgelaufen(Debug.FINE),

	/**
	 * Parameter: 1) PID Meldung.
	 */
	FineMeldungUngueltig(Debug.FINE),

	/** Ohne Paramater. */
	FineAlleThreadsGestartet(Debug.FINE),

	/** Ohne Paramater. */
	FineMengenAenderung(Debug.FINE),

	/** Ohne Paramater. */
	FineVerwaltungKomplett(Debug.FINE),

	/** Ohne Paramater. */
	FineParametrierungEmpfangen(Debug.FINE),

	/** Parameter: 1) Typ des Auftrags. */
	FineAuftragEmpfangen(Debug.FINE),

	/** Parameter: 1) Application-ID, 2) lfd. Nr, 3) Typ des Auftrags. */
	FineAuftragEingefuegt(Debug.FINE),

	/** Parameter: 1) PID Meldung. */
	FineMeldungObjekt(Debug.FINE),

	/** Parameter: 1) PID Meldung. */
	FineMeldungDatenAnmelden(Debug.FINE),

	/** Parameter: 1) PID Meldung. */
	FineMeldungDatenPublizieren(Debug.FINE);

	/** Das Resource-Bundle. */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(LmsMsg.class.getCanonicalName());

	/** Die Eigenschaft {@code level}. */
	private final Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	LmsMsg(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		if (level.equals(Debug.WARNING)) {
			return MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			return MessageGrade.ERROR;
		}

		// Spezialbehandlungen
		if (this.equals(InfoMeldungAufgehoben)) {
			return MessageGrade.INFORMATION;
		}

		if (this.equals(InfoStatusEingehendOK)) {
			return MessageGrade.INFORMATION;
		}

		if (this.equals(InfoStatusAusgehendOK)) {
			return MessageGrade.INFORMATION;
		}

		return null;
	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return LmsMsg.RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
