/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Boolean;

/**
 * TIC3-Regel der Ergebniserzeugung.
 * <p>
 * Entspricht TIC3-Typ 'CreateResultRuleType'.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3ErgebnisErzeugungRegel.java 63650 2016-09-22 17:11:32Z gieseler $
 */
public class TIC3ErgebnisErzeugungRegel extends AbstractTIC3InfoElement {
	/**
	 * TIC3 Info XML Element: Rule (RUL), A list of rules to be used when this source data is used to create the data contained in this object.
	 */
	public static final String XML_ELEMENT_REGEL = "Rule";
	
	/**
	 * Verwenden.
	 * <p>
	 * TIC3 Info XML Element: Use (USE), Specifies whether or not the element is used to create the data contained in this object.
	 * </p>
	 */
	private TIC3Boolean verwenden = new TIC3Boolean("Use", "Verwenden");	
	
	/**
	 * Elementpfad.
	 * <p>
	 * TIC3 Info XML Element: ElementPath (ELP), The address of the element which was combined, consisting of the path from the root of the object type to the element and the element identifier.
	 * </p>
	 */
	private TIC3Text elementpfad = new TIC3Text("ElementPath", "Elementpfad");	

	/**
	 * Elementschlüssel.
	 * <p>
	 *TIC3 Info XML Element: ElementKey (ELV), The key of the element which was combined.
	 * </p>
	 */
	private TIC3Text elementschluessel = new TIC3Text("ElementKey", "Elementschlüssel");	

	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3ErgebnisErzeugungRegel() {
		this(XML_ELEMENT_REGEL, null);
	}

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3ErgebnisErzeugungRegel(final String xmlName, final String davName) {
		super(xmlName, davName);
		addKindElement(verwenden);
		addKindElement(elementpfad);
		addKindElement(elementschluessel);
	}
	

	@Override
	public String toString() {
		return this.getClass().getSimpleName(); 
	}
}
