/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tmc;

import de.bsvrz.dav.daf.main.Data;

/**
 * Repr&auml;sentiert ein mehrwertiges TIC3-Infoelement.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TMCZustand.java 63650 2016-09-22 17:11:32Z gieseler $
 */

public class TMCZustand {

	private String davattr;
	private int wert;

	/**
	 * Konstruktor.
	 * 
	 * @param davattr
	 *            Name des DAV-Attributes
	 * @param wert
	 *            Wert des Attributes
	 */
	public TMCZustand(final String davattr, final int wert) {
		super();
		this.davattr = davattr;
		this.wert = wert;
	}

	/**
	 * Setzt die DAV-Daten.
	 * 
	 * @param davdata
	 *            {@link Data}
	 * @throws TMCException
	 *             bei Fehlern
	 */
	public void setDavDaten(final Data davdata) throws TMCException {
		if (davdata.isPlain()) {
			davdata.asUnscaledValue().set(wert);
		} else {
			davdata.getUnscaledValue(davattr).set(wert);

			if (!davdata.getUnscaledValue(davattr).isState()) {
				throw new TMCException("Der Wert '" + wert + "' für das Attribut '" + davattr
						+ "' kann nicht auf einen Zustand abgebildet werden");
			}
		}
	}

	@Override
	public String toString() {
		return this.getClass().getSimpleName() + ": DAV-Attribut: " + davattr + ", Wert: " + wert;
	}
}
